summaryrefslogtreecommitdiffstats
path: root/chrome/views/view.h
diff options
context:
space:
mode:
authorklink@chromium.org <klink@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-28 00:12:01 +0000
committerklink@chromium.org <klink@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-28 00:12:01 +0000
commite92070ac9982489502180c006fe7911889c8fbee (patch)
tree577f25e7a8b61fd5b497886f57d89770f19f60cb /chrome/views/view.h
parentec7690fc03aef949ea4eece3c17b3f78b265006e (diff)
downloadchromium_src-e92070ac9982489502180c006fe7911889c8fbee.zip
chromium_src-e92070ac9982489502180c006fe7911889c8fbee.tar.gz
chromium_src-e92070ac9982489502180c006fe7911889c8fbee.tar.bz2
Removes the use of Windows-specific types for accessibility roles and states in Views and Browser\Views. Helps with the porting effort, and makes for a cleaner implementation.
Review URL: http://codereview.chromium.org/93085 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@14689 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/views/view.h')
-rw-r--r--chrome/views/view.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/chrome/views/view.h b/chrome/views/view.h
index f88ad7e..b502842 100644
--- a/chrome/views/view.h
+++ b/chrome/views/view.h
@@ -20,6 +20,7 @@
#include "base/gfx/rect.h"
#include "base/scoped_ptr.h"
+#include "chrome/common/accessibility_types.h"
#include "chrome/views/accelerator.h"
#include "chrome/views/background.h"
#include "chrome/views/border.h"
@@ -559,19 +560,19 @@ class View : public AcceleratorTarget {
// successful.
virtual bool GetAccessibleName(std::wstring* name) { return false; }
-#if defined(OS_WIN)
- // TODO(port): Make these functions using VARIANT portable.
-
- // Returns the MSAA role of the current view. The role is what assistive
- // technologies (ATs) use to determine what behavior to expect from a given
- // control. Sets the input VARIANT appropriately, and returns true if
+ // Returns the accessibility role of the current view. The role is what
+ // assistive technologies (ATs) use to determine what behavior to expect from
+ // a given control. Sets the input Role appropriately, and returns true if
// successful.
- virtual bool GetAccessibleRole(VARIANT* role) { return false; }
+ virtual bool GetAccessibleRole(AccessibilityTypes::Role* role) {
+ return false;
+ }
- // Returns the MSAA state of the current view. Sets the input VARIANT
- // appropriately, and returns true if a change was performed successfully.
- virtual bool GetAccessibleState(VARIANT* state) { return false; }
-#endif // defined(OS_WIN)
+ // Returns the accessibility state of the current view. Sets the input State
+ // appropriately, and returns true if successful.
+ virtual bool GetAccessibleState(AccessibilityTypes::State* state) {
+ return false;
+ }
// Assigns a keyboard shortcut string description to the given control. Needed
// as a View does not know which shortcut will be associated with it until it